@@ -8,11 +8,12 @@
 
 #include <gnome.h>
 
-#include "globals.h"
+#include "same-gnome.h"
 
 #include "drawing.h"
 #include "game.h"
 #include "input.h"
+#include "ui.h"
 
 /* Record offsets for the moving tiles to avoid any possibility of
  * error due to rounding effects and havint to do cut and paste math
@@ -38,6 +39,8 @@ GdkPixmap *blank_pixmap = NULL;
 /* FIXME: Can we make this not global ? (redraw is the problem) */
 GtkWidget *canvaswidget;
 
+gint drawing_area_width = 0;;
+
 gint cursor_x = -1;
 gint cursor_y = -1;
 gboolean draw_cursor = FALSE;
@@ -211,6 +214,7 @@ static gboolean render_cb (GtkWidget *canvas)
 	guchar *p, *bp;
 	guint shift;
 	gchar *filename;
+	GtkWidget *dialog;
 
 	if (idle_state == INIT) {
 		last_tile_size = tile_size;
@@ -253,11 +257,19 @@ static gboolean render_cb (GtkWidget *canvas)
 										 0, 0, 0, 0, tile_size, tile_size, GDK_RGB_DITHER_NORMAL,
 										 0, 0);
 
-		/* FIXME: We should also look in the users home directory. */
-		filename = g_build_filename (THEMEDIR, theme, NULL);
+		/* FIXME: We should also look for different suffices, e.g.
+		 * in case of a .png -> .svg changeover. */
+		/* First look in the players home directory. */
+		filename = g_build_filename (localthemedir, theme, NULL);
 		if (!g_file_test (filename, G_FILE_TEST_EXISTS)) {
-			g_free (filename);
-			filename = g_build_filename (THEMEDIR, DEFAULT_THEME, NULL);			
+			g_free (filename);		
+			/* Then look in the system directory. */
+			filename = g_build_filename (THEMEDIR, theme, NULL);
+			if (!g_file_test (filename, G_FILE_TEST_EXISTS)) {
+				g_free (filename);
+				/* And finallyy fall back to the default. */
+				filename = g_build_filename (THEMEDIR, DEFAULT_THEME, NULL);			
+			}
 		}
 
 		file_pixbuf = gdk_pixbuf_new_from_file_at_size (filename,
@@ -267,10 +279,26 @@ static gboolean render_cb (GtkWidget *canvas)
 		g_free (filename);
 
 		idle_state = DRAW;
-		/* FIXME: No fallback if we fail to open the file. */
+
+		/* Do something halfway sensible in the absense of any data. */
+		if (file_pixbuf == NULL) {
+			/* FIXME: We haven't got the parent window right. */
+			dialog = gtk_message_dialog_new (NULL,
+																			 GTK_DIALOG_MODAL | 
+																			 GTK_DIALOG_DESTROY_WITH_PARENT,
+																			 GTK_MESSAGE_ERROR,
+																			 GTK_BUTTONS_NONE,
+																			 _("No theme data was found."));
+			gtk_dialog_add_button (GTK_DIALOG (dialog), GTK_STOCK_QUIT, 
+														 GTK_RESPONSE_OK);
+			gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
+																								_("It is impossible to play the game. Please check that the game has been installed correctly and try again."));
+			gtk_dialog_run (GTK_DIALOG (dialog));
+			gtk_main_quit ();
+			return FALSE;
+		}
 	} else if (idle_state == DRAW) {
 		if (last_tile_size != tile_size) {
-			g_print ("Redraw\n");
 			idle_state = INIT;
 		} else {
 			if (pixmaps[n][m] != NULL)
@@ -469,7 +497,6 @@ static gboolean render_cb (GtkWidget *canvas)
 		g_object_unref (bg_pixbuf);
 		bg_pixbuf = NULL;
 		idle_state = INIT;
-		g_print ("Done ?\n");
 
 		if (pixmaps_ready) /* Just in case this was reset after the last idle call. */
 			return FALSE;
@@ -477,27 +504,52 @@ static gboolean render_cb (GtkWidget *canvas)
 	return TRUE;
 }
 
-gboolean configure_cb (GtkWidget *canvas, GdkEventConfigure *event)
+static void start_renderer (void)
+{
+	pixmaps_ready = FALSE;
+	
+	if (idle_id == 0)
+		g_idle_add ((GSourceFunc)render_cb, canvaswidget);
+	
+	if (resize_timeout_id != 0)
+		g_source_remove (resize_timeout_id);
+	resize_timeout_id = g_timeout_add (300, (GSourceFunc)redraw_cb, 
+																		 canvaswidget);
+}
+
+void change_theme (gchar *newtheme)
+{
+	if (g_utf8_collate (theme, newtheme) != 0) {
+
+		g_free (theme);
+		theme = g_strdup (newtheme);
+
+		start_renderer ();
+		redraw ();
+		
+		gconf_client_set_string (gcclient, GCONF_THEME_KEY, theme, NULL);
+	}
+}
+
+void resize_graphics (void)
 {
 	int size;
 
-	canvaswidget = canvas;
-
-	size = event->width/board_width;
+	size = drawing_area_width/board_width;
 
 	if (tile_size != size) {
 
 		tile_size = size;
 
-		pixmaps_ready = FALSE;
-
-		if (idle_id == 0)
-			g_idle_add ((GSourceFunc)render_cb, canvas);
-
-		if (resize_timeout_id != 0)
-			g_source_remove (resize_timeout_id);
-		resize_timeout_id = g_timeout_add (300, (GSourceFunc)redraw_cb, canvas);
+		start_renderer ();
 	}
+}
+
+gboolean configure_cb (GtkWidget *canvas, GdkEventConfigure *event)
+{
+	canvaswidget = canvas;
+	drawing_area_width = event->width;
+	resize_graphics ();
 
   return FALSE;
 }
@@ -608,10 +660,7 @@ static gboolean animation_timer (void)
 					game_state = GAME_MOVING_LEFT;
 					speed = 1.0;
 				} else {
-					game_state = GAME_IDLE;
-					/* FIXME: The setting of GAME_IDLE and end_of_game_check seem to go
-					 * together, can this be simplified. */
-					end_of_game_check ();
+					end_of_move ();
 				}
 			else {
 				game_state = GAME_MOVING_DOWN;
@@ -626,8 +675,7 @@ static gboolean animation_timer (void)
 				if (mark_shifting_balls ()) {
 					game_state = GAME_MOVING_LEFT;
 				} else {
-					game_state = GAME_IDLE;
-					end_of_game_check ();
+					end_of_move ();
 					select_cells ();
 				}
 				speed = 1.0;
@@ -637,8 +685,7 @@ static gboolean animation_timer (void)
 			break;
 		case GAME_MOVING_LEFT:
 			if (!mark_shifting_balls ()) {
-				game_state = GAME_IDLE;
-				end_of_game_check ();
+				end_of_move ();
 				select_cells ();
 			}
 			break;
@@ -655,6 +702,8 @@ void start_spinning (void)
 	game_cell *p;
 	coordinates *list;
 	
+	set_message (count);
+
 	/* FIXME: Is this bit of policy distributed too far ? */
 	if (count <= 1)
 		return;
